@@ -6,11 +6,12 @@ from roborabbit.rmq import create_from_config
 
 
 class RoboRabbit:
+    connection = None
+
     def __init__(self, path, connection: Connection = None):
         self.connection_config = connection
         self.path = path
         self.initialized = False
-        self.connection = None
         self.queues = None
 
     async def _startup(self):
